====
pydl
====

Description
-----------

Python replacements for functions that are part of the IDL_ built-in library, or
part of astronomical IDL libraries.  The emphasis is on reproducing results of
the astronomical library functions.  Only the bare minimum of IDL_ built-in
functions are implemented to support this.

There are four astronomical IDL libraries targeted:

* idlutils_ : a general suite of tools heavily used by SDSS
* `Goddard utilities`_ : The IDL Astronomy User's Libary, maintained by Wayne Landsman and distributed with idlutils.
* idlspec2d_ : tools for working with SDSS/BOSS spectroscopic data
* photoop_ : tools for working with SDSS imaging data

This package affiliated with the astropy_ project and is registered with PyPI_.

History
-------

This code was initially developed on the SDSS-III_ `svn repository`_.  It was
moved to the new GitHub_ repository on 2013-03-06.  The present location of
the repository is http://github.com/weaverba137/pydl .

.. _IDL: http://www.exelisvis.com/language/en-us/productsservices/idl.aspx
.. _idlutils: http://www.sdss3.org/dr9/software/idlutils.php
.. _`Goddard utilities`: http://idlastro.gsfc.nasa.gov/
.. _idlspec2d: http://www.sdss3.org/svn/repo/idlspec2d/trunk/
.. _photoop: http://www.sdss3.org/svn/repo/photoop/trunk/
.. _astropy: http://www.astropy.org/
.. _PyPI: https://pypi.python.org/pypi/pydl/
.. _SDSS-III: http://www.sdss3.org/
.. _`svn repository`: http://www.sdss3.org/dr9/software/products.php
.. _GitHub: http://github.com/
